@@ -41,13 +41,17 @@ class Snaplib:
         plt.xticks(np.arange(0.5, len(df.columns), 1), df.columns, rotation=80)
         plt.show()
         return plt
-        
 
 
 
 
 
-    def cleane(cls, df, target=None, verbose=True):
+
+
+
+
+
+    def cleane(df, target=None, verbose=True):
         '''drop_duplicates, drop rows with nan in target, drop column with 1 unique value'''
         
         # DROP DUPLICATES
@@ -89,7 +93,7 @@ class Snaplib:
         if verbose:
             print(f'shape: {df.shape}\n')
             print(f'\nFinish shape: {df.shape}\n')
-            cls.nan_plot(df)
+            Snaplib.nan_plot(df)
         return df
 
 
@@ -97,6 +101,10 @@ class Snaplib:
 
 
 
+
+
+
+
     def train_test_split_balanced(df, target_feature, test_size=0.33, random_state=0, research_iter=0):
         
         CLASSIFIER_FOR_UNIQUE_VALUES_LESS_THAN = 50
@@ -270,7 +278,11 @@ class Snaplib:
 
 
 
-    def recover_data(cls, 
+
+
+
+
+    def recover_data(
                     data_input_0, 
                     target = None,   # For prediction at the end
                     verbose = 1,
@@ -395,9 +407,7 @@ class Snaplib:
         data_input = data_input_0.copy()
 
         if verbose:
-            cls.nan_plot(data_input)
-            # plt.figure(figsize=(20, 5))
-            # sns.heatmap(data_input.isnull(), cbar=False)
+            Snaplib.nan_plot(data_input)
                 
         data_info = get_data_info(data_input)
         if verbose:
@@ -624,9 +634,7 @@ class Snaplib:
         data_input.index = data_input_indeces
 
         if verbose:
-            cls.nan_plot(data_input)
-            # plt.figure(figsize=(20, 5))
-            # sns.heatmap(data_input.isnull(), cbar=False)
+            Snaplib.nan_plot(data_input)
             print('\n\n\n')
             data_info = get_data_info(data_input)
             print(data_info)
